@@ -55,7 +55,7 @@ class EnvironementConfig:
         self.DATE = self.DATE or date.today().isoformat()
         self.S3_BUCKET = self.S3_BUCKET or self.NESTOR_NAME
         self.DB_NAME = self.DB_NAME or self.PROD_INSTANCE_NAME
-        self.ODOO_DEPENDS = self.ODOO_DEPENDS or ("odoo-addons/common-modules,odoo-addons/community-addons")
+        self.ODOO_DEPENDS = self.ODOO_DEPENDS or "odoo-addons/common-modules,odoo-addons/community-addons"
         dump_path_fmt = "%(PROD_INSTANCE_NAME)s/journaliere/%(DB_NAME)s_%(DATE)s.dump"
         self.DUMP_PATH = (self.DUMP_PATH or dump_path_fmt) % {
             "PROD_INSTANCE_NAME": self.PROD_INSTANCE_NAME,
@@ -64,7 +64,6 @@ class EnvironementConfig:
         }
         self.NESTOR_CFG_FILENAME = self.NESTOR_CFG_FILENAME or ".nestor-cfg.yml"
         self.BASE_MODULE_UPDATE = self.BASE_MODULE_UPDATE or "all"
-        self.ODOO_DEPENDS = self.ODOO_DEPENDS or "odoo-addons/common-modules,odoo-addons/community-addons"
         self.S3_SECRET_PREVIEW = self.S3_SECRET_PREVIEW or "s3-ndp-preview"
         self.S3_DUMP_SECRET = self.S3_DUMP_SECRET or "s3-ndp-scaleway"
         self.S3_DUMP_BUCKET = self.S3_DUMP_BUCKET or "ndp-production-backups"
@@ -102,6 +101,8 @@ class InteractiveConfig(EnvironementConfig):
         if self.CI_PROJECT_PATH:
             if not self.CI_PROJECT_PATH.startswith("/"):
                 self.CI_PROJECT_PATH = "odoo-addons/" + self.CI_PROJECT_PATH
+            else:
+                self.CI_PROJECT_PATH = self.CI_PROJECT_PATH.removeprefix("/")
         else:
             log("Un projet est obligatoire")
             sys.exit(1)
@@ -127,6 +128,9 @@ class InteractiveConfig(EnvironementConfig):
         log(f"Date du dump à utiliser (format ISO YYYY-MM-DD) || default = {date.today().isoformat()}")
         self.DATE = input("=> ") or self.DATE
 
+        log(f"Odoo depends || default = odoo-addons/common-modules,odoo-addons/community-addons")
+        self.ODOO_DEPENDS = input("=> ") or self.ODOO_DEPENDS
+
         log(f"Token Gitlab (Vide pour utiliser '{self.GITLAB_TOKEN}')")
         self.GITLAB_TOKEN = input("=> ") or self.GITLAB_TOKEN
 
